@@ -16,10 +16,12 @@
 
 from __future__ import annotations
 
+import contextlib
 import dataclasses
 from typing import Iterable
 
 from etils import epy
+import pytest
 
 
 @dataclasses.dataclass
@@ -33,12 +35,24 @@ class A(epy.ContextManager):
     self.state.append(f'end:{self.x}')
 
 
-def test_contextmanager():
-  with A(1) as a1:
+@dataclasses.dataclass(frozen=True)
+class AFrozen(epy.ContextManager):
+  x: int
+  state: list[str] = dataclasses.field(default_factory=list)
+
+  def __contextmanager__(self) -> Iterable[AFrozen]:
+    self.state.append(f'start:{self.x}')
+    yield self
+    self.state.append(f'end:{self.x}')
+
+
+@pytest.mark.parametrize('cls', [A, AFrozen])
+def test_contextmanager(cls: type[A]):
+  with cls(1) as a1:
     assert a1.x == 1
 
     # Different instances can be nested (and don't share state)
-    with A(2) as a2:
+    with cls(2) as a2:
       assert a2.x == 2
 
     assert a1.state == ['start:1']
@@ -51,3 +65,18 @@ def test_contextmanager():
     assert a1.state == ['start:1', 'end:1', 'start:1']
 
   assert a1.state == ['start:1', 'end:1', 'start:1', 'end:1']
+
+
+def test_exitstack():
+  a1 = A(1)
+  a2 = A(2)
+
+  assert a1.state == []  # pylint: disable=g-explicit-bool-comparison
+  assert a2.state == []  # pylint: disable=g-explicit-bool-comparison
+  with epy.ExitStack([a1, a2]) as stack:
+    assert isinstance(stack, contextlib.ExitStack)
+    assert a1.state == ['start:1']
+    assert a2.state == ['start:2']
+
+  assert a1.state == ['start:1', 'end:1']
+  assert a2.state == ['start:2', 'end:2']
